pub struct TypeSafeId<T> { /* private fields */ }Expand description
A typed UUID.
use type_safe_id::{StaticType, TypeSafeId};
#[derive(Default)]
struct User;
impl StaticType for User {
// must be lowercase ascii [a-z] only
const TYPE: &'static str = "user";
}
// type alias for your custom typed id
type UserId = TypeSafeId<User>;
let user_id1 = UserId::new();
let user_id2 = UserId::new();
let uid1 = user_id1.to_string();
let uid2 = user_id2.to_string();
dbg!(&uid1, &uid2);
assert!(uid2 > uid1, "type safe IDs are ordered");
let user_id3: UserId = uid1.parse().expect("invalid user id");
let user_id4: UserId = uid2.parse().expect("invalid user id");
assert_eq!(user_id1.uuid(), user_id3.uuid(), "round trip works");
assert_eq!(user_id2.uuid(), user_id4.uuid(), "round trip works");Implementations
Sourceimpl<T: StaticType> TypeSafeId<T>
impl<T: StaticType> TypeSafeId<T>
Sourceimpl<T: Type> TypeSafeId<T>
impl<T: Type> TypeSafeId<T>
Sourcepub fn new_with_type(type_prefix: T) -> Self
pub fn new_with_type(type_prefix: T) -> Self
Create a new type-id with the given type prefix
Sourcepub fn from_type_and_uuid(type_prefix: T, data: Uuid) -> Self
pub fn from_type_and_uuid(type_prefix: T, data: Uuid) -> Self
Create a new type-id with the given type prefix and uuid data
pub fn type_prefix(&self) -> &str
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
The length of a type-id string with the given type
If your prefix is static, you can also use TypeSafeId::static_len.
pub fn uuid(&self) -> Uuid